package
Version:
v0.0.0-...-9f22829
Opens a new window with list of versions in this module.
Published: Sep 24, 2019
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type RealSleep struct {
}
RealSleep is real sleep
type Sleeper interface {
Sleep()
}
Sleeper is interface
Source Files
¶
Click to show internal directories.
Click to hide internal directories.